Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Addon ¶
type Addon interface {
InitMetadata(string) (*Metadata, error)
InitProfile(string) error
Install(string) error
}
Addon represents an interface defining functionality for managing World of Warcraft addons.
type Curse ¶
Curse represents the corresponding interface from addon.Addon
func (*Curse) InitMetadata ¶
InitMetadata returns the metadata object of an addon parsed from Curse where the curse addon id is specified by id. Return an error if one occurred.
func (*Curse) InitProfile ¶
InitProfile creates a new profile (wam.json) with the World of Warcraft installation path specified by f. Return an error if one occurred.
Click to show internal directories.
Click to hide internal directories.